﻿


;-------------------------------------------------------------------------------
setupTaskbar(hWnd) { ; set up Taskbar Ornaments
;-------------------------------------------------------------------------------
    global AppName
    IconLib := AppName ".icl"

    ; attach interface to main gui, specify button callback function
    tbi := new taskbarInterface(hWnd, "buttonCallback")

    ; get the required size for the button icons
    sz := tbi.queryButtonIconSize() ; gives {w: 32, h: 32} on Win10


    ;---------------------------------------------------------------------------
    ; Button 1: change word list
    ;---------------------------------------------------------------------------
    hIcon := LoadPicture(IconLib, "icon1 w" sz.w " h" sz.h, isIcon)
    tbi.setButtonIcon(1, hIcon)                     ; set icon for button 1
    tbi.setButtonTooltip(1, "Change word list")     ; tooltip for button 1
    tbi.disableButton(1)                            ; start disabled
    tbi.showButton(1)                               ; show it


    ;---------------------------------------------------------------------------
    ; Button 2: save current anagrams to file
    ;---------------------------------------------------------------------------
    hIcon := LoadPicture(IconLib, "icon2 w" sz.w " h" sz.h, isIcon)
    tbi.setButtonIcon(2, hIcon)                     ; set icon for button 2
    tbi.setButtonTooltip(2, "Save anagrams...")     ; tooltip for button 2
    tbi.disableButton(2)                            ; start disabled
    tbi.showButton(2)                               ; show it


    ;---------------------------------------------------------------------------
    ; overlay icons - used in showAnagrams: along side spinner.start()/stop()
    ;---------------------------------------------------------------------------
    tbi.hOverlaySearching := LoadPicture(IconLib, "icon3", isIcon)  ; magnifying glass
    tbi.hOverlayLoading := LoadPicture(IconLib, "icon4", isIcon)    ; loading icon
    tbi.hOverlayDone := LoadPicture(IconLib, "icon5", isIcon)       ; green check mark
    tbi.setOverlayIcon(tbi.hOverlayLoading)                         ; loading first

    Return, tbi
}



;-------------------------------------------------------------------------------
buttonCallback(n, ref) { ; button callback function
;-------------------------------------------------------------------------------


    ;---------------------------------------------------------------------------
    If (n == 1) { ; handle button 1
    ;---------------------------------------------------------------------------
        global WordList, WordCount, WCount

        ; construct PipedList
        Loop, Files, Word lists\*.txt
            PipedList .= A_LoopFileName "|"
        PipedList := RTrim(PipedList, "|")

        ; show dialog
        If Answer := RadioBox("Change word list", "Select a word list:", PipedList) {
            FileCopy, Word lists\%Answer%, Words.txt, 1 ; overwrite

            ; change word list
            Gui, Main: Default
            GuiControl, Show, Loading
            GuiControlGet, LastInput,, Input
            GuiControl, +Disabled +Center -g, Input
            GuiControl, +Disabled, WCount
            GuiControl, +Disabled, Skip
            GuiControl, +Disabled, LView
            SB_SetText("", 3)
            SB_SetText("", 4)

            WordCount := Make_DICT()

            SB_SetText("Words: " prettify_Number(WordCount), 3)
            GuiControl, -g, Input
            GuiControl, -Disabled -Center +gShowAnagrams, Input
            GuiControl,, Input, %LastInput%
            GuiControl, -Disabled, WCount
            If (WCount = 1) ; single words
                GuiControl, -Disabled, Skip
            GuiControl, -Disabled, LView
            GuiControl, Hide, Loading
        }
    }


    ;---------------------------------------------------------------------------
    Else If (n == 2) { ; handle button 2
    ;---------------------------------------------------------------------------
        global Input

        ; make sure folder exists before calling FileSelectFile,,, RootDir
        If Not InStr(FileExist(Folder := A_ScriptDir "\Saved anagrams"), "D")
            FileCreateDir, %Folder%

        ; no taskbar button for this dialog, use main icon for this dialog
        Gui, Main: +OwnDialogs
        FileSelectFile, Path, S 16      ; S=Save button 16=Prompt to OverWrite
            , %Folder%\%Input%.txt      ; RootDir\Filename
            , Select file to save to    ; Prompt
            , Text files (*.txt)        ; Filter

        IfEqual, Path,, Return ; user cancelled dialog

        If SubStr(Path, -3) != ".txt" ; last 4 characters
            Path .= ".txt"

        FileDelete, %Path%
        FileAppend, % StrReplace(WordList, "|", "`r`n"), %Path%
    }
}
